#!/bin/bash

# Dateipfade deklarieren
rulespath=/usr/share/X11/xkb/rules/evdev.xml
symbolspath=/usr/share/X11/xkb/symbols/de

backuprulespath=/usr/share/X11/xkb/rules/evdev.xml_oldbackup
backupsymbolspath=/usr/share/X11/xkb/symbols/de_oldbackup

layoutrules=./rules/layoutrules.xml
layoutsymbols=./symbols/layoutsymbols

echo "Die Installation wird vorbereitet ..."

# LXDE (Lubuntu): Die Belegungen in die Konfigurationsdatei einfügen
lxdeconfig=/usr/share/lxpanel/xkeyboardconfig/layouts.cfg
backuplxdeconfig=/usr/share/lxpanel/xkeyboardconfig/layouts.cfg_oldbackup

if test -f "$lxdeconfig";
then
    echo "Für die Installation sind Administratorrechte erforderlich."
    echo "Bitte geben Sie Ihr Passwort ein."
    sudo echo

    echo "LXDE (Lubuntu) spezifische Dateien:" 

    # Falls Backup der Konfigurationsdatei existiert, stelle es wieder her.
    if test -f "$backuplxdeconfig";
    then
        echo "Die Detei $backuplxdeconfig existiert bereits ..."
        echo "Stelle Anfangszustand von $lxdeconfig wieder her."
        sudo mv $backuplxdeconfig $lxdeconfig
    fi
    # Erstelle ein Backup der Konfigurationsdatei
    echo "Es wird eine Sicherheitskopie der Datei $lxdeconfig erstellt ..."
    sudo cp $lxdeconfig $backuplxdeconfig
        echo "Die Sicherheitskopie wurde gespeichert als $backuplxdeconfig ..."

    echo "Trage neue Belegungen in die Tastaturliste von LXDE (Lubuntu) ein."
    sudo sed -i "s/de(ru) = Russian (Germany, phonetic)/de(ru) = Russian (Germany, phonetic)\nde(ru-recom) = Russisch (Deutschland, empfohlen)\nde(ru-translit) = Russisch (Deutschland, Transliteration)/g" $lxdeconfig

    echo ""
fi


# Erstelle eine Sicherheitskopie der Datei evdev.xml, aber nur wenn noch keine Kopie existiert
if test -f "$backuprulespath"; 
then 
    echo "Die Datei $backuprulespath existiert bereits ..."
    
    # Überprüfe, ob auch eine Sicherheitskopie der Datei de existiert
    if test -f "$backupsymbolspath";
    then
        echo "Die Datei $backupsymbolspath existiert ebenfalls ..."
        echo ""
        echo "HINWEIS: Die Tastaturlayouts sind bereits installiert und sollten in den"  
        echo "         Tastatureinstellungen vorhanden sein. Eventuell ist ein Neustart"
        echo "         erforderlich. Sollten (weiterhin) Fehler auftreten,"
        echo "         deinstallieren Sie die Tastaturlayouts mit der Datei" 
        echo "         'uninstall.sh'. Führen Sie anschließend die Installation erneut aus."  
        echo "         Sollten weiterhin Fehler auftreten, kontaktieren Sie bitte die"
        echo "         Entwickler. (Kontaktdaten finden Sie auf der Homepage, auf der Sie"
        echo "         diese Installationsdateien heruntergeladen haben.)"
        echo ""
        echo "Bitte LESEN Sie den obigen Hinweis." 
        echo "Um das Terminal zu schließen, drücken Sie [ENTER]:"
        read warten
    else
        echo "Die Datei $backupsymbolspath existiert nicht ..."
        echo ""
        echo "HINWEIS: Es scheint, als sei ein Fehler bei der Installation aufgetreten."
        echo "         Bitte deinstallieren Sie die Tastaturlayouts mit der Datei"
        echo "         'uninstall.sh'. Führen Sie anschließend die Installation erneut aus."  
        echo "         Sollten weiterhin Fehler auftreten, kontaktieren Sie bitte die"
        echo "         Entwickler. (Kontaktdaten finden Sie auf der Homepage, auf der Sie"
        echo "         diese Installationsdateien heruntergeladen haben.)"
        echo ""
        echo "Bitte LESEN Sie den obigen Hinweis." 
        echo "Um das Terminal zu schließen, drücken Sie [ENTER]:"
        read warten
    fi
     
else
    echo "Für die Installation sind Administratorrechte erforderlich."
    echo "Bitte geben Sie Ihr Passwort ein."
    sudo echo

    echo "Es wird eine Sicherheitskopie der Datei $rulespath erstellt ..."
    sudo cp $rulespath $backuprulespath
    echo "Die Sicherheitskopie wurde gespeichert als $backuprulespath ..."
    
    # Überprüfe, ob eine Sicherheitskopie der Datei de existiert
    if test -f "$backupsymbolspath";
    then
        echo "Die Datei $backupsymbolspath existiert bereits ..."
        echo ""
        echo "HINWEIS: Es scheint, als sei ein Fehler bei der Installation aufgetreten."
        echo "         Bitte deinstallieren Sie die Tastaturlayouts mit der Datei"
        echo "         'uninstall.sh'. Führen Sie anschließend die Installation erneut aus."  
        echo "         Sollten weiterhin Fehler auftreten, kontaktieren Sie bitte die"
        echo "         Entwickler. (Kontaktdaten finden Sie auf der Homepage, auf der Sie"
        echo "         diese Installationsdateien heruntergeladen haben.)"
        echo ""
        echo "Bitte LESEN Sie den obigen Hinweis." 
        echo "Um das Terminal zu schließen, drücken Sie [ENTER]:"
        read warten
    else
        echo "Es wird eine Sicherheitskopie der Datei $symbolspath erstellt ..."
        sudo cp $symbolspath $backupsymbolspath
        echo "Die Sicherheitskopie wurde gespeichert als $backupsymbolspath ..."
               
        
        ##################### Füge den Code aus layoutrules.xml in evdev.xml ein #########################
        
        # Zeilennummer, in der sich "Russian (Germany, phonetic)" befindet, herausfinden
        declare -i russianlinenumber=($(grep -n "Russian (Germany, phonetic)" $rulespath | cut -d : -f1))      
        echo "Die Zeile 'Russian (Germany, phonetic)' befindet sich in Zeile: $russianlinenumber ..."
        
        # Finde die Zeilennummer der Zeile, die "</variant>" enthält und direkt nach obiger Zeile kommt.
        declare -i variantlinenumber=($(tail -n +$(($russianlinenumber+1)) $rulespath | grep -m 1 -n "</variant>" | cut -d : -f1))
        
        # Zeilennummer, in die der Codeblock später eingefügt werden soll, initialisieren
        declare -i insertlinenumber=$(($russianlinenumber + $variantlinenumber))
        echo "Die Zeile '</variant>' befindet sich $variantlinenumber Zeilen weiter, also in Zeile: $insertlinenumber ..."
        
        # Layout-Regeln aus der Datei layoutrules.xml in die Datei evdev.xml einfügen
        echo "Trage Layout-Regeln in die Datei $rulespath ein ..."
        sudo sed -i -e "$insertlinenumber r $layoutrules" $rulespath 
        echo "Die Layout-Regeln aus $layoutrules wurden in die Datei $rulespath eingetragen ..."
        
        
        #################### Füge den Code aus layoutsymbols in die Datei de ein #########################
        
        # Füge leere Zeile am Ende der Datei de ein, dies dient nur der Optik des Codes
        sudo sh -c "echo '' >> $symbolspath"
        
        # Finde die Anzahl der Zeilen in der Datei de heraus
        declare -i numberoflinesinde=($(wc -l < $symbolspath))
        echo "Die Anzahl der Zeilen in der Datei $symbolspath ist: $numberoflinesinde"
        
        # Layout-Symbole aus der Datei layoutsymbols in die Datei de einfügen
        echo "Trage Layout-Symbole in die Datei $symbolspath ein ..."
        sudo sed -i -e "$numberoflinesinde r $layoutsymbols" $symbolspath 
        echo "Die Layout-Symbole aus $layoutsymbols wurden in die Datei $symbolspath eingetragen ..."

        ###############################################  QED ############################################
        
		sudo dpkg-reconfigure xkb-data

        echo ""
        echo "Die Installation war ERFOLGREICH (eventuell Neustart erforderlich)."
        echo "Um die Installation zu beenden, drücken Sie [ENTER]:"
        read warten
        
    fi
    
fi
